@@ -17,23 +17,20 @@
 
 package org.apache.kyuubi.engine.spark.operation
 
-import org.apache.spark.sql.SparkSession
 import org.apache.spark.sql.types._
 
-import org.apache.kyuubi.engine.spark.IterableFetchIterator
 import org.apache.kyuubi.engine.spark.shim.SparkCatalogShim
-import org.apache.kyuubi.operation.OperationType
+import org.apache.kyuubi.operation.{IterableFetchIterator, OperationType}
 import org.apache.kyuubi.operation.meta.ResultSetSchemaConstant._
 import org.apache.kyuubi.session.Session
 
 class GetColumns(
-    spark: SparkSession,
     session: Session,
     catalogName: String,
     schemaName: String,
     tableName: String,
     columnName: String)
-  extends SparkOperation(spark, OperationType.GET_COLUMNS, session) {
+  extends SparkOperation(OperationType.GET_COLUMNS, session) {
 
   override def statement: String = {
     super.statement +
