@@ -19,21 +19,19 @@ package org.apache.kyuubi.engine.spark.operation
 
 import java.sql.DatabaseMetaData
 
-import org.apache.spark.sql.{Row, SparkSession}
+import org.apache.spark.sql.Row
 import org.apache.spark.sql.types.StructType
 
-import org.apache.kyuubi.engine.spark.IterableFetchIterator
-import org.apache.kyuubi.operation.OperationType
+import org.apache.kyuubi.operation.{IterableFetchIterator, OperationType}
 import org.apache.kyuubi.operation.meta.ResultSetSchemaConstant._
 import org.apache.kyuubi.session.Session
 
 class GetFunctions(
-    spark: SparkSession,
     session: Session,
     catalogName: String,
     schemaName: String,
     functionName: String)
-  extends SparkOperation(spark, OperationType.GET_FUNCTIONS, session) {
+  extends SparkOperation(OperationType.GET_FUNCTIONS, session) {
 
   override def statement: String = {
     super.statement +
