@@ -19,16 +19,15 @@ package org.apache.kyuubi.engine.spark.operation
 
 import java.sql.Types._
 
-import org.apache.spark.sql.{Row, SparkSession}
+import org.apache.spark.sql.Row
 import org.apache.spark.sql.types.StructType
 
-import org.apache.kyuubi.engine.spark.IterableFetchIterator
-import org.apache.kyuubi.operation.OperationType
+import org.apache.kyuubi.operation.{IterableFetchIterator, OperationType}
 import org.apache.kyuubi.operation.meta.ResultSetSchemaConstant._
 import org.apache.kyuubi.session.Session
 
-class GetTypeInfo(spark: SparkSession, session: Session)
-  extends SparkOperation(spark, OperationType.GET_TYPE_INFO, session) {
+class GetTypeInfo(session: Session)
+  extends SparkOperation(OperationType.GET_TYPE_INFO, session) {
   override protected def resultSchema: StructType = {
     new StructType()
       .add(TYPE_NAME, "string", nullable = false, "Type name")
@@ -78,7 +77,7 @@ class GetTypeInfo(spark: SparkSession, session: Session)
 
   private def isNumericType(javaType: Int): Boolean = {
     javaType == TINYINT || javaType == SMALLINT || javaType == INTEGER || javaType == BIGINT ||
-    javaType == FLOAT || javaType == FLOAT || javaType == DOUBLE || javaType == DECIMAL
+    javaType == FLOAT || javaType == DOUBLE || javaType == DECIMAL
   }
 
   private def toRow(name: String, javaType: Int, precision: Integer = null): Row = {
