@@ -18,8 +18,12 @@
 package org.apache.kyuubi.engine.spark.session
 
 import org.apache.hive.service.rpc.thrift.TProtocolVersion
+import org.apache.spark.sql.{AnalysisException, SparkSession}
 
-import org.apache.kyuubi.engine.spark.events.{EventLoggingService, SessionEvent}
+import org.apache.kyuubi.engine.spark.events.SessionEvent
+import org.apache.kyuubi.engine.spark.operation.SparkSQLOperationManager
+import org.apache.kyuubi.engine.spark.udf.KDFRegistry
+import org.apache.kyuubi.events.EventLogging
 import org.apache.kyuubi.operation.{Operation, OperationHandle}
 import org.apache.kyuubi.session.{AbstractSession, SessionHandle, SessionManager}
 
@@ -27,16 +31,33 @@ class SparkSessionImpl(
     protocol: TProtocolVersion,
     user: String,
     password: String,
+    serverIpAddress: String,
     ipAddress: String,
     conf: Map[String, String],
-    sessionManager: SessionManager)
+    sessionManager: SessionManager,
+    val spark: SparkSession)
   extends AbstractSession(protocol, user, password, ipAddress, conf, sessionManager) {
   override val handle: SessionHandle = SessionHandle(protocol)
 
+  private def setModifiableConfig(key: String, value: String): Unit = {
+    try {
+      spark.conf.set(key, value)
+    } catch {
+      case e: AnalysisException => warn(e.getMessage())
+    }
+  }
+
   private val sessionEvent = SessionEvent(this)
 
+  def serverIpAddress(): String = serverIpAddress
+
   override def open(): Unit = {
-    EventLoggingService.onEvent(sessionEvent)
+    normalizedConf.foreach {
+      case ("use:database", database) => spark.catalog.setCurrentDatabase(database)
+      case (key, value) => setModifiableConfig(key, value)
+    }
+    KDFRegistry.registerAll(spark)
+    EventLogging.onEvent(sessionEvent)
     super.open()
   }
 
@@ -47,8 +68,10 @@ class SparkSessionImpl(
 
   override def close(): Unit = {
     sessionEvent.endTime = System.currentTimeMillis()
-    EventLoggingService.onEvent(sessionEvent)
+    EventLogging.onEvent(sessionEvent)
     super.close()
+    spark.sessionState.catalog.getTempViewNames().foreach(spark.catalog.uncacheTable(_))
+    sessionManager.operationManager.asInstanceOf[SparkSQLOperationManager].closeILoop(handle)
   }
 
 }
