@@ -23,8 +23,9 @@ import org.apache.spark.scheduler._
 import org.apache.spark.sql.SparkSession
 import org.apache.spark.sql.execution.ui.SparkListenerSQLExecutionEnd
 
-import org.apache.kyuubi.KyuubiSparkUtils._
 import org.apache.kyuubi.Logging
+import org.apache.kyuubi.config.KyuubiReservedKeys.KYUUBI_STATEMENT_ID_KEY
+import org.apache.kyuubi.engine.spark.KyuubiSparkUtil.SPARK_SQL_EXECUTION_ID_KEY
 import org.apache.kyuubi.operation.Operation
 import org.apache.kyuubi.operation.log.OperationLog
 
@@ -43,6 +44,8 @@ class SQLOperationListener(
   private val activeStages = new java.util.HashSet[Int]()
   private var executionId: Option[Long] = None
 
+  def getExecutionId: Option[Long] = executionId
+
   // For broadcast, Spark will introduce a new runId as SPARK_JOB_GROUP_ID, see:
   // https://github.com/apache/spark/pull/24595, So we will miss these logs.
   // TODO: Fix this until the below ticket resolved
