@@ -29,11 +29,11 @@ import org.apache.commons.text.StringEscapeUtils
 import org.apache.spark.ui.TableSourceUtil._
 import org.apache.spark.ui.UIUtils._
 
-import org.apache.kyuubi.Utils
-import org.apache.kyuubi.engine.spark.events.{SessionEvent, SparkStatementEvent}
+import org.apache.kyuubi.{KYUUBI_VERSION, Utils}
+import org.apache.kyuubi.engine.spark.events.{SessionEvent, SparkOperationEvent}
 
 case class EnginePage(parent: EngineTab) extends WebUIPage("") {
-  private val store = parent.engine.store
+  private val store = parent.store
 
   override def render(request: HttpServletRequest): Seq[Node] = {
     val content =
@@ -42,8 +42,8 @@ case class EnginePage(parent: EngineTab) extends WebUIPage("") {
         stop(request) ++
         <br/> ++
         <h4>
-        {parent.engine.backendService.sessionManager.getOpenSessionCount} session(s) are online,
-        running {parent.engine.backendService.sessionManager.operationManager.getOperationCount}
+        {store.getSessionCount} session(s) are online,
+        running {store.getStatementCount}
         operations
       </h4> ++
         generateSessionStatsTable(request) ++
@@ -52,28 +52,40 @@ case class EnginePage(parent: EngineTab) extends WebUIPage("") {
   }
 
   private def generateBasicStats(): Seq[Node] = {
-    val timeSinceStart = System.currentTimeMillis() - parent.engine.getStartTime
+    val timeSinceStart = parent.endTime() - parent.startTime
     <ul class ="list-unstyled">
       <li>
-        <strong>Started at: </strong>
-        {new Date(parent.engine.getStartTime)}
+        <strong>Kyuubi Version: </strong>
+        {KYUUBI_VERSION}
       </li>
       <li>
-        <strong>Latest Logout at: </strong>
-        {new Date(parent.engine.backendService.sessionManager.latestLogoutTime)}
+        <strong>Started at: </strong>
+        {new Date(parent.startTime)}
       </li>
+    {
+      parent.engine.map { engine =>
+        <li>
+            <strong>Latest Logout at: </strong>
+            {new Date(engine.backendService.sessionManager.latestLogoutTime)}
+          </li>
+      }.getOrElse(Seq.empty)
+    }
       <li>
         <strong>Time since start: </strong>
         {formatDurationVerbose(timeSinceStart)}
       </li>
-      <li>
-        <strong>Background execution pool threads alive: </strong>
-        {parent.engine.backendService.sessionManager.getExecPoolSize}
-      </li>
-      <li>
-        <strong>Background execution pool threads active: </strong>
-        {parent.engine.backendService.sessionManager.getActiveCount}
-      </li>
+    {
+      parent.engine.map { engine =>
+        <li>
+          <strong>Background execution pool threads alive: </strong>
+          {engine.backendService.sessionManager.getExecPoolSize}
+        </li>
+        <li>
+          <strong>Background execution pool threads active: </strong>
+          {engine.backendService.sessionManager.getActiveCount}
+        </li>
+      }.getOrElse(Seq.empty)
+    }
     </ul>
   }
 
@@ -236,6 +248,7 @@ case class EnginePage(parent: EngineTab) extends WebUIPage("") {
         Seq(
           ("User", true, None),
           ("Client IP", true, None),
+          ("Server IP", true, None),
           ("Session ID", true, None),
           ("Start Time", true, None),
           ("Finish Time", true, None),
@@ -260,6 +273,7 @@ case class EnginePage(parent: EngineTab) extends WebUIPage("") {
       <tr>
         <td> {session.username} </td>
         <td> {session.ip} </td>
+        <td> {session.serverIp} </td>
         <td> <a href={sessionLink}> {session.sessionId} </a> </td>
         <td> {formatDate(session.startTime)} </td>
         <td> {if (session.endTime > 0) formatDate(session.endTime)} </td>
@@ -274,10 +288,10 @@ case class EnginePage(parent: EngineTab) extends WebUIPage("") {
 private class StatementStatsPagedTable(
     request: HttpServletRequest,
     parent: EngineTab,
-    data: Seq[SparkStatementEvent],
+    data: Seq[SparkOperationEvent],
     subPath: String,
     basePath: String,
-    sqlStatsTableTag: String) extends PagedTable[SparkStatementEvent] {
+    sqlStatsTableTag: String) extends PagedTable[SparkOperationEvent] {
 
   private val (sortColumn, desc, pageSize) =
     getRequestTableParameters(request, sqlStatsTableTag, "Create Time")
@@ -321,7 +335,8 @@ private class StatementStatsPagedTable(
         ("Duration", true, None),
         ("Statement", true, None),
         ("State", true, None),
-        ("Query Execution", true, None))
+        ("Query Details", true, None),
+        ("Failure Reason", true, None))
 
     headerStatRow(
       sqlTableHeadersAndTooltips,
@@ -333,32 +348,45 @@ private class StatementStatsPagedTable(
       sqlStatsTableTag)
   }
 
-  override def row(sparkStatementEvent: SparkStatementEvent): Seq[Node] = {
+  override def row(event: SparkOperationEvent): Seq[Node] = {
     <tr>
       <td>
-        {sparkStatementEvent.username}
+        {event.sessionUser}
       </td>
       <td>
-        {sparkStatementEvent.statementId}
+        {event.statementId}
       </td>
       <td >
-        {formatDate(sparkStatementEvent.createTime)}
+        {formatDate(event.createTime)}
       </td>
       <td>
-        {if (sparkStatementEvent.completeTime > 0) formatDate(sparkStatementEvent.completeTime)}
+        {if (event.completeTime > 0) formatDate(event.completeTime)}
       </td>
       <td >
-        {formatDurationVerbose(sparkStatementEvent.duration)}
+        {formatDurationVerbose(event.duration)}
       </td>
       <td>
         <span class="description-input">
-          {sparkStatementEvent.statement}
+          {event.statement}
         </span>
       </td>
       <td>
-        {sparkStatementEvent.state}
+        {event.state}
       </td>
-      {errorMessageCell(sparkStatementEvent.exception)}
+      <td>
+        {
+      if (event.executionId.isDefined) {
+        <a href={
+          "%s/SQL/execution/?id=%s".format(
+            UIUtils.prependBaseUri(request, parent.basePath),
+            event.executionId.get)
+        }>
+          {event.executionId.get}
+          </a>
+      }
+    }
+      </td>
+      {if (event.exception.isDefined) errorMessageCell(event.exception.get.getMessage)}
     </tr>
   }
 
@@ -398,6 +426,7 @@ private class SessionStatsTableDataSource(
     val ordering: Ordering[SessionEvent] = sortColumn match {
       case "User" => Ordering.by(_.username)
       case "Client IP" => Ordering.by(_.ip)
+      case "Server IP" => Ordering.by(_.serverIp)
       case "Session ID" => Ordering.by(_.sessionId)
       case "Start Time" => Ordering.by(_.startTime)
       case "Finish Time" => Ordering.by(_.endTime)
@@ -414,31 +443,32 @@ private class SessionStatsTableDataSource(
 }
 
 private class StatementStatsTableDataSource(
-    info: Seq[SparkStatementEvent],
+    info: Seq[SparkOperationEvent],
     pageSize: Int,
     sortColumn: String,
-    desc: Boolean) extends PagedDataSource[SparkStatementEvent](pageSize) {
+    desc: Boolean) extends PagedDataSource[SparkOperationEvent](pageSize) {
 
   // Sorting SessionEvent data
   private val data = info.sorted(ordering(sortColumn, desc))
 
   override def dataSize: Int = data.size
 
-  override def sliceData(from: Int, to: Int): Seq[SparkStatementEvent] = data.slice(from, to)
+  override def sliceData(from: Int, to: Int): Seq[SparkOperationEvent] = data.slice(from, to)
 
   /**
    * Return Ordering according to sortColumn and desc.
    */
-  private def ordering(sortColumn: String, desc: Boolean): Ordering[SparkStatementEvent] = {
-    val ordering: Ordering[SparkStatementEvent] = sortColumn match {
-      case "User" => Ordering.by(_.username)
+  private def ordering(sortColumn: String, desc: Boolean): Ordering[SparkOperationEvent] = {
+    val ordering: Ordering[SparkOperationEvent] = sortColumn match {
+      case "User" => Ordering.by(_.sessionUser)
       case "Statement ID" => Ordering.by(_.statementId)
       case "Create Time" => Ordering.by(_.createTime)
       case "Finish Time" => Ordering.by(_.completeTime)
       case "Duration" => Ordering.by(_.duration)
       case "Statement" => Ordering.by(_.statement)
       case "State" => Ordering.by(_.state)
-      case "Query Execution" => Ordering.by(_.queryExecution)
+      case "Query Details" => Ordering.by(_.executionId)
+      case "Failure Reason" => Ordering.by(_.exception.toString)
       case unknownColumn => throw new IllegalArgumentException(s"Unknown column: $unknownColumn")
     }
     if (desc) {
