@@ -23,7 +23,7 @@ object OperationType extends Enumeration {
 
   type OperationType = Value
   val UNKNOWN_OPERATION, EXECUTE_STATEMENT, GET_TYPE_INFO, GET_CATALOGS, GET_SCHEMAS, GET_TABLES,
-      GET_TABLE_TYPES, GET_COLUMNS, GET_FUNCTIONS, LAUNCH_ENGINE = Value
+      GET_TABLE_TYPES, GET_COLUMNS, GET_FUNCTIONS = Value
 
   def getOperationType(from: TOperationType): OperationType = {
     from match {
