@@ -28,6 +28,17 @@ import org.apache.kyuubi.service.authentication.AuthMethods.AuthMethod
 object AuthenticationProviderFactory {
   @throws[AuthenticationException]
   def getAuthenticationProvider(
+      method: AuthMethod,
+      conf: KyuubiConf,
+      isServer: Boolean = true): PasswdAuthenticationProvider = {
+    if (isServer) {
+      getAuthenticationProviderForServer(method, conf)
+    } else {
+      getAuthenticationProviderForEngine(conf)
+    }
+  }
+
+  private def getAuthenticationProviderForServer(
       method: AuthMethod,
       conf: KyuubiConf): PasswdAuthenticationProvider = method match {
     case AuthMethods.NONE => new AnonymousAuthenticationProviderImpl
@@ -57,4 +68,12 @@ object AuthenticationProviderFactory {
       }
     case _ => throw new AuthenticationException("Not a valid authentication method")
   }
+
+  private def getAuthenticationProviderForEngine(conf: KyuubiConf): PasswdAuthenticationProvider = {
+    if (conf.get(KyuubiConf.ENGINE_SECURITY_ENABLED)) {
+      new EngineSecureAuthenticationProviderImpl
+    } else {
+      new AnonymousAuthenticationProviderImpl
+    }
+  }
 }
