@@ -34,7 +34,7 @@ import org.apache.kyuubi.config.KyuubiConf
 import org.apache.kyuubi.config.KyuubiConf._
 import org.apache.kyuubi.service.authentication.AuthTypes._
 
-class KyuubiAuthenticationFactory(conf: KyuubiConf) extends Logging {
+class KyuubiAuthenticationFactory(conf: KyuubiConf, isServer: Boolean = true) extends Logging {
 
   private val authTypes = conf.get(AUTHENTICATION_METHOD).map(AuthTypes.withName)
   private val noSasl = authTypes == Seq(NOSASL)
@@ -56,6 +56,10 @@ class KyuubiAuthenticationFactory(conf: KyuubiConf) extends Logging {
     }
   }
 
+  if (conf.get(ENGINE_SECURITY_ENABLED)) {
+    EngineSecurityAccessor.initialize(conf, isServer)
+  }
+
   private def getSaslProperties: java.util.Map[String, String] = {
     val props = new java.util.HashMap[String, String]()
     val qop = SaslQOP.withName(conf.get(SASL_QOP))
@@ -87,7 +91,8 @@ class KyuubiAuthenticationFactory(conf: KyuubiConf) extends Logging {
           transportFactory = PlainSASLHelper.getTransportFactory(
             plainAuthType.toString,
             conf,
-            Option(transportFactory)).asInstanceOf[TSaslServerTransport.Factory]
+            Option(transportFactory),
+            isServer).asInstanceOf[TSaslServerTransport.Factory]
 
         case _ =>
       }
