@@ -52,7 +52,8 @@ object TestUtils {
       }
       reader.close()
       val hint = s"$markdown out of date, please update doc with " +
-        s"KYUUBI_UPDATE=1 build/mvn clean install -Pspark-provided -DwildcardSuites=$agent"
+        s"KYUUBI_UPDATE=1 build/mvn clean install -Pflink-provided,spark-provided " +
+        s"-DwildcardSuites=$agent"
       assert(newOutput.size === expected.size, hint)
 
       newOutput.zip(expected).foreach { case (out, in) => assert(out === in, hint) }
