@@ -35,8 +35,7 @@ object HighAvailabilityConf {
     .createWithDefault("")
 
   val HA_ZK_NAMESPACE: ConfigEntry[String] = buildConf("ha.zookeeper.namespace")
-    .doc("The root directory for the service to deploy its instance uri. Additionally, it will" +
-      " creates a -[username] suffixed root directory for each application")
+    .doc("The root directory for the service to deploy its instance uri")
     .version("1.0.0")
     .stringConf
     .createWithDefault("kyuubi")
@@ -149,4 +148,12 @@ object HighAvailabilityConf {
       .version("1.4.0")
       .booleanConf
       .createWithDefault(false)
+
+  val HA_ZK_ENGINE_SECURE_SECRET_NODE: OptionalConfigEntry[String] =
+    buildConf("ha.zookeeper.engine.secure.secret.node")
+      .doc("The zk node contains the secret that used for internal secure between Kyuubi server " +
+        "and Kyuubi engine, please make sure that it is only visible for Kyuubi.")
+      .version("1.5.0")
+      .stringConf
+      .createOptional
 }
