@@ -22,18 +22,23 @@ import java.util.concurrent.locks.ReentrantLock
 import scala.collection.JavaConverters._
 
 import org.apache.hive.service.rpc.thrift._
-import org.apache.thrift.protocol.TProtocol
+import org.apache.thrift.protocol.{TBinaryProtocol, TProtocol}
+import org.apache.thrift.transport.TSocket
 
 import org.apache.kyuubi.{KyuubiSQLException, Logging}
+import org.apache.kyuubi.config.KyuubiConf
+import org.apache.kyuubi.config.KyuubiConf.{ENGINE_LOGIN_TIMEOUT, ENGINE_REQUEST_TIMEOUT}
 import org.apache.kyuubi.operation.FetchOrientation
 import org.apache.kyuubi.operation.FetchOrientation.FetchOrientation
+import org.apache.kyuubi.service.authentication.PlainSASLHelper
 import org.apache.kyuubi.session.SessionHandle
 import org.apache.kyuubi.util.ThriftUtils
 
-class KyuubiSyncThriftClient(protocol: TProtocol)
+class KyuubiSyncThriftClient private (protocol: TProtocol)
   extends TCLIService.Client(protocol) with Logging {
 
   @volatile private var _remoteSessionHandle: TSessionHandle = _
+  @volatile private var _engineId: Option[String] = _
 
   private val lock = new ReentrantLock()
 
@@ -50,6 +55,8 @@ class KyuubiSyncThriftClient(protocol: TProtocol)
     } finally lock.unlock()
   }
 
+  def engineId: Option[String] = _engineId
+
   /**
    * Return the engine SessionHandle for kyuubi session so that we can get the same session id
    */
@@ -65,22 +72,36 @@ class KyuubiSyncThriftClient(protocol: TProtocol)
     val resp = withLockAcquired(OpenSession(req))
     ThriftUtils.verifyTStatus(resp.getStatus)
     _remoteSessionHandle = resp.getSessionHandle
+    _engineId = Option(resp.getConfiguration)
+      .filter(_.containsKey("kyuubi.engine.id"))
+      .map(_.get("kyuubi.engine.id"))
     SessionHandle(_remoteSessionHandle, protocol)
   }
 
   def closeSession(): Unit = {
-    val req = new TCloseSessionReq(_remoteSessionHandle)
-    val resp = withLockAcquired(CloseSession(req))
-    ThriftUtils.verifyTStatus(resp.getStatus)
+    try {
+      if (_remoteSessionHandle != null) {
+        val req = new TCloseSessionReq(_remoteSessionHandle)
+        val resp = withLockAcquired(CloseSession(req))
+        ThriftUtils.verifyTStatus(resp.getStatus)
+      }
+    } catch {
+      case e: Exception =>
+        throw KyuubiSQLException("Error while cleaning up the engine resources", e)
+    } finally {
+      if (protocol.getTransport.isOpen) protocol.getTransport.close()
+    }
   }
 
   def executeStatement(
       statement: String,
+      confOverlay: Map[String, String],
       shouldRunAsync: Boolean,
       queryTimeout: Long): TOperationHandle = {
     val req = new TExecuteStatementReq()
     req.setSessionHandle(_remoteSessionHandle)
     req.setStatement(statement)
+    req.setConfOverlay(confOverlay.asJava)
     req.setRunAsync(shouldRunAsync)
     req.setQueryTimeout(queryTimeout)
     val resp = withLockAcquired(ExecuteStatement(req))
@@ -195,10 +216,6 @@ class KyuubiSyncThriftClient(protocol: TProtocol)
     resp.getSchema
   }
 
-  override def FetchResults(req: TFetchResultsReq): TFetchResultsResp = {
-    withLockAcquired(super.FetchResults(req))
-  }
-
   def fetchResults(
       operationHandle: TOperationHandle,
       orientation: FetchOrientation,
@@ -208,7 +225,7 @@ class KyuubiSyncThriftClient(protocol: TProtocol)
     val req = new TFetchResultsReq(operationHandle, or, maxRows)
     val fetchType = if (fetchLog) 1.toShort else 0.toShort
     req.setFetchType(fetchType)
-    val resp = FetchResults(req)
+    val resp = withLockAcquired(FetchResults(req))
     ThriftUtils.verifyTStatus(resp.getStatus)
     resp.getResults
   }
@@ -231,3 +248,21 @@ class KyuubiSyncThriftClient(protocol: TProtocol)
     }
   }
 }
+
+private[kyuubi] object KyuubiSyncThriftClient {
+  def createClient(
+      user: String,
+      password: String,
+      host: String,
+      port: Int,
+      conf: KyuubiConf): KyuubiSyncThriftClient = {
+    val passwd = Option(password).filter(_.nonEmpty).getOrElse("anonymous")
+    val loginTimeout = conf.get(ENGINE_LOGIN_TIMEOUT).toInt
+    val requestTimeout = conf.get(ENGINE_REQUEST_TIMEOUT).toInt
+    val tSocket = new TSocket(host, port, requestTimeout, loginTimeout)
+    val tTransport = PlainSASLHelper.getPlainTransport(user, passwd, tSocket)
+    tTransport.open()
+    val tProtocol = new TBinaryProtocol(tTransport)
+    new KyuubiSyncThriftClient(tProtocol)
+  }
+}
