@@ -17,10 +17,15 @@
 
 package org.apache.kyuubi.credentials
 
+import java.util.concurrent.atomic.AtomicReference
+
+import scala.concurrent.Future
+import scala.concurrent.duration.Duration
+
 import org.apache.hadoop.security.Credentials
 
 import org.apache.kyuubi.credentials.CredentialsRef.UNSET_EPOCH
-import org.apache.kyuubi.util.KyuubiHadoopUtils
+import org.apache.kyuubi.util.{KyuubiHadoopUtils, ThreadUtils}
 
 class CredentialsRef(appUser: String) {
 
@@ -29,6 +34,12 @@ class CredentialsRef(appUser: String) {
 
   private var encodedCredentials: String = _
 
+  private val credentialFuture = new AtomicReference[Future[Unit]]()
+
+  def setFuture(future: Future[Unit]): Unit = {
+    credentialFuture.set(future)
+  }
+
   def getEpoch: Long = epoch
 
   def getAppUser: String = appUser
@@ -42,6 +53,10 @@ class CredentialsRef(appUser: String) {
     epoch += 1
   }
 
+  def waitUntilReady(timeout: Duration): Unit = {
+    Option(credentialFuture.get).foreach(ThreadUtils.awaitResult(_, timeout))
+  }
+
 }
 
 object CredentialsRef {
