@@ -23,6 +23,8 @@ import org.apache.hive.service.rpc.thrift.TRowSet
 
 import org.apache.kyuubi.config.KyuubiConf
 import org.apache.kyuubi.config.KyuubiConf.OPERATION_QUERY_TIMEOUT
+import org.apache.kyuubi.metrics.MetricsConstants.OPERATION_OPEN
+import org.apache.kyuubi.metrics.MetricsSystem
 import org.apache.kyuubi.operation.FetchOrientation.FetchOrientation
 import org.apache.kyuubi.session.{KyuubiSessionImpl, Session}
 import org.apache.kyuubi.util.ThriftUtils
@@ -52,10 +54,11 @@ class KyuubiOperationManager private (name: String) extends OperationManager(nam
   override def newExecuteStatementOperation(
       session: Session,
       statement: String,
+      confOverlay: Map[String, String],
       runAsync: Boolean,
       queryTimeout: Long): Operation = {
     val operation =
-      new ExecuteStatement(session, statement, runAsync, getQueryTimeout(queryTimeout))
+      new ExecuteStatement(session, statement, confOverlay, runAsync, getQueryTimeout(queryTimeout))
     addOperation(operation)
   }
 
@@ -135,4 +138,9 @@ class KyuubiOperationManager private (name: String) extends OperationManager(nam
         }
     }
   }
+
+  override def start(): Unit = synchronized {
+    MetricsSystem.tracing(_.registerGauge(OPERATION_OPEN, getOperationCount, 0))
+    super.start()
+  }
 }
