@@ -17,27 +17,12 @@
 
 package org.apache.kyuubi.server.api
 
-import io.swagger.v3.jaxrs2.integration.resources.OpenApiResource
-import io.swagger.v3.oas.annotations.OpenAPIDefinition
-import io.swagger.v3.oas.annotations.info.{Contact, Info, License}
-import io.swagger.v3.oas.annotations.tags.Tag
 import org.glassfish.jersey.server.ResourceConfig
 
-@OpenAPIDefinition(
-  info = new Info(
-    title = "Apache Kyuubi REST API Documentation",
-    version = "1.4.0",
-    description = "Apache Kyuubi REST API Documentation",
-    contact = new Contact(
-      name = "Apache Kyuubi Community",
-      url = "https://kyuubi.apache.org/issue_tracking.html",
-      email = "dev@kyuubi.apache.org"),
-    license = new License(
-      name = "Apache 2.0",
-      url = "https://www.apache.org/licenses/LICENSE-2.0.html")),
-  tags = Array(new Tag(name = "Session")))
+import org.apache.kyuubi.server.api.v1.KyuubiOpenApiResource
+
 class OpenAPIConfig extends ResourceConfig {
   packages("org.apache.kyuubi.server.api.v1")
-  register(classOf[OpenApiResource]);
+  register(classOf[KyuubiOpenApiResource])
   register(classOf[KyuubiScalaObjectMapper])
 }
