@@ -17,25 +17,23 @@
 
 package org.apache.kyuubi.session
 
+import scala.collection.JavaConverters._
+
 import com.codahale.metrics.MetricRegistry
 import org.apache.hive.service.rpc.thrift._
-import org.apache.thrift.TException
-import org.apache.thrift.protocol.TBinaryProtocol
-import org.apache.thrift.transport.{TSocket, TTransport}
 
 import org.apache.kyuubi.KyuubiSQLException
 import org.apache.kyuubi.client.KyuubiSyncThriftClient
 import org.apache.kyuubi.config.KyuubiConf
 import org.apache.kyuubi.config.KyuubiConf._
 import org.apache.kyuubi.engine.EngineRef
-import org.apache.kyuubi.events.KyuubiSessionEvent
+import org.apache.kyuubi.events.{EventLogging, KyuubiEvent, KyuubiSessionEvent}
 import org.apache.kyuubi.ha.client.ZooKeeperClientProvider._
 import org.apache.kyuubi.metrics.MetricsConstants._
 import org.apache.kyuubi.metrics.MetricsSystem
-import org.apache.kyuubi.operation.{Operation, OperationHandle}
+import org.apache.kyuubi.operation.{Operation, OperationHandle, OperationState}
 import org.apache.kyuubi.operation.log.OperationLog
-import org.apache.kyuubi.server.EventLoggingService
-import org.apache.kyuubi.service.authentication.PlainSASLHelper
+import org.apache.kyuubi.service.authentication.EngineSecurityAccessor
 
 class KyuubiSessionImpl(
     protocol: TProtocolVersion,
@@ -43,32 +41,44 @@ class KyuubiSessionImpl(
     password: String,
     ipAddress: String,
     conf: Map[String, String],
-    override val sessionManager: KyuubiSessionManager,
+    sessionManager: KyuubiSessionManager,
     sessionConf: KyuubiConf)
   extends AbstractSession(protocol, user, password, ipAddress, conf, sessionManager) {
+  override val handle: SessionHandle = SessionHandle(protocol)
+
+  private[kyuubi] val optimizedConf: Map[String, String] = {
+    val confOverlay = sessionManager.sessionConfAdvisor.getConfOverlay(
+      user,
+      normalizedConf.asJava)
+    if (confOverlay != null) {
+      normalizedConf ++ confOverlay.asScala
+    } else {
+      warn(s"the server plugin return null value for user: $user, ignore it")
+      normalizedConf
+    }
+  }
 
   // TODO: needs improve the hardcode
-  normalizedConf.foreach {
+  optimizedConf.foreach {
     case ("use:database", _) =>
     case ("kyuubi.engine.pool.size.threshold", _) =>
     case (key, value) => sessionConf.set(key, value)
   }
 
   val engine: EngineRef = new EngineRef(sessionConf, user)
-  val launchEngineAsync = sessionConf.get(SESSION_ENGINE_LAUNCH_ASYNC)
-  private[kyuubi] val launchEngineOp =
-    sessionManager.operationManager.newLaunchEngineOperation(this, launchEngineAsync)
-  @volatile
-  var engineLaunched: Boolean = false
+  private[kyuubi] val launchEngineOp = sessionManager.operationManager
+    .newLaunchEngineOperation(this, sessionConf.get(SESSION_ENGINE_LAUNCH_ASYNC))
 
   private val sessionEvent = KyuubiSessionEvent(this)
-  EventLoggingService.onEvent(sessionEvent)
+  EventLogging.onEvent(sessionEvent)
+
+  override def getSessionEvent: Option[KyuubiEvent] = {
+    Option(sessionEvent)
+  }
 
-  private var transport: TTransport = _
   private var _client: KyuubiSyncThriftClient = _
   def client: KyuubiSyncThriftClient = _client
 
-  override val handle: SessionHandle = SessionHandle(protocol)
   private var _engineSessionHandle: SessionHandle = _
 
   override def open(): Unit = {
@@ -86,25 +96,19 @@ class KyuubiSessionImpl(
   private[kyuubi] def openEngineSession(extraEngineLog: Option[OperationLog] = None): Unit = {
     withZkClient(sessionConf) { zkClient =>
       val (host, port) = engine.getOrCreate(zkClient, extraEngineLog)
-      val passwd = Option(password).filter(_.nonEmpty).getOrElse("anonymous")
-      val loginTimeout = sessionConf.get(ENGINE_LOGIN_TIMEOUT).toInt
-      val requestTimeout = sessionConf.get(ENGINE_REQUEST_TIMEOUT).toInt
-      transport = PlainSASLHelper.getPlainTransport(
-        user,
-        passwd,
-        new TSocket(host, port, requestTimeout, loginTimeout))
-      if (!transport.isOpen) {
-        transport.open()
-        logSessionInfo(s"Connected to engine [$host:$port]")
-      }
-      _client = new KyuubiSyncThriftClient(new TBinaryProtocol(transport))
-      _engineSessionHandle = _client.openSession(protocol, user, passwd, normalizedConf)
-      logSessionInfo(s"Opened engine session[${_engineSessionHandle}]")
+      val passwd =
+        if (sessionManager.getConf.get(ENGINE_SECURITY_ENABLED)) {
+          EngineSecurityAccessor.get().issueToken()
+        } else {
+          Option(password).filter(_.nonEmpty).getOrElse("anonymous")
+        }
+      _client = KyuubiSyncThriftClient.createClient(user, passwd, host, port, sessionConf)
+      _engineSessionHandle = _client.openSession(protocol, user, passwd, optimizedConf)
+      logSessionInfo(s"Connected to engine [$host:$port] with ${_engineSessionHandle}")
       sessionEvent.openedTime = System.currentTimeMillis()
-      sessionEvent.sessionId = handle.identifier.toString
       sessionEvent.remoteSessionId = _engineSessionHandle.identifier.toString
-      sessionEvent.clientVersion = handle.protocol.getValue
-      EventLoggingService.onEvent(sessionEvent)
+      _client.engineId.foreach(e => sessionEvent.engineId = e)
+      EventLogging.onEvent(sessionEvent)
     }
   }
 
@@ -116,6 +120,8 @@ class KyuubiSessionImpl(
     super.runOperation(operation)
   }
 
+  @volatile private var engineLaunched: Boolean = false
+
   private def waitForEngineLaunched(): Unit = {
     if (!engineLaunched) {
       Option(launchEngineOp).foreach { op =>
@@ -129,7 +135,7 @@ class KyuubiSessionImpl(
 
         if (_engineSessionHandle == null) {
           val ex = op.getStatus.exception.getOrElse(
-            KyuubiSQLException(s"Failed to launch engine for session[$handle]"))
+            KyuubiSQLException(s"Failed to launch engine for $handle"))
           throw ex
         }
 
@@ -139,23 +145,17 @@ class KyuubiSessionImpl(
   }
 
   override def close(): Unit = {
-    if (!launchEngineOp.isTimedOut) {
+    if (!OperationState.isTerminal(launchEngineOp.getStatus.state)) {
       closeOperation(launchEngineOp.getHandle)
     }
     super.close()
     sessionManager.credentialsManager.removeSessionCredentialsEpoch(handle.identifier.toString)
     try {
       if (_client != null) _client.closeSession()
-    } catch {
-      case e: TException =>
-        throw KyuubiSQLException("Error while cleaning up the engine resources", e)
     } finally {
       sessionEvent.endTime = System.currentTimeMillis()
-      EventLoggingService.onEvent(sessionEvent)
+      EventLogging.onEvent(sessionEvent)
       MetricsSystem.tracing(_.decCount(MetricRegistry.name(CONN_OPEN, user)))
-      if (transport != null && transport.isOpen) {
-        transport.close()
-      }
     }
   }
 }
