@@ -27,6 +27,7 @@ import org.apache.kyuubi.credentials.HadoopCredentialsManager
 import org.apache.kyuubi.metrics.MetricsConstants._
 import org.apache.kyuubi.metrics.MetricsSystem
 import org.apache.kyuubi.operation.KyuubiOperationManager
+import org.apache.kyuubi.plugin.{PluginLoader, SessionConfAdvisor}
 
 class KyuubiSessionManager private (name: String) extends SessionManager(name) {
 
@@ -34,6 +35,8 @@ class KyuubiSessionManager private (name: String) extends SessionManager(name) {
 
   val operationManager = new KyuubiOperationManager()
   val credentialsManager = new HadoopCredentialsManager()
+  // this lazy is must be specified since the conf is null when the class initialization
+  lazy val sessionConfAdvisor: SessionConfAdvisor = PluginLoader.loadSessionConfAdvisor(conf)
 
   override def initialize(conf: KyuubiConf): Unit = {
     addService(credentialsManager)
@@ -50,13 +53,14 @@ class KyuubiSessionManager private (name: String) extends SessionManager(name) {
       conf: Map[String, String]): SessionHandle = {
 
     val username = Option(user).filter(_.nonEmpty).getOrElse("anonymous")
-
+    // inject client ip into session conf
+    val newConf = conf + (CLIENT_IP_KEY -> ipAddress)
     val sessionImpl = new KyuubiSessionImpl(
       protocol,
       username,
       password,
       ipAddress,
-      conf,
+      newConf,
       this,
       this.getConf.getUserDefaults(user))
     try {
