@@ -19,6 +19,7 @@ package org.apache.kyuubi
 
 import org.apache.kyuubi.config.KyuubiConf
 import org.apache.kyuubi.config.KyuubiConf._
+import org.apache.kyuubi.config.KyuubiConf.FrontendProtocols.FrontendProtocol
 import org.apache.kyuubi.ha.HighAvailabilityConf.{HA_ZK_AUTH_TYPE, HA_ZK_QUORUM}
 import org.apache.kyuubi.ha.client.ZooKeeperAuthTypes
 import org.apache.kyuubi.server.KyuubiServer
@@ -28,7 +29,7 @@ trait WithKyuubiServer extends KyuubiFunSuite {
 
   protected val conf: KyuubiConf
 
-  protected val frontendProtocols: Seq[FrontendProtocols.Value] =
+  protected val frontendProtocols: Seq[FrontendProtocol] =
     FrontendProtocols.THRIFT_BINARY :: Nil
 
   private var zkServer: EmbeddedZookeeper = _
@@ -51,8 +52,8 @@ trait WithKyuubiServer extends KyuubiFunSuite {
 
     conf.set("spark.ui.enabled", "false")
     conf.setIfMissing("spark.sql.catalogImplementation", "in-memory")
-    conf.setIfMissing(ENGINE_CHECK_INTERVAL, 3000L)
-    conf.setIfMissing(ENGINE_IDLE_TIMEOUT, 10000L)
+    conf.setIfMissing(ENGINE_CHECK_INTERVAL, 1000L)
+    conf.setIfMissing(ENGINE_IDLE_TIMEOUT, 3000L)
     // TODO KYUUBI #745
     conf.setIfMissing(ENGINE_INIT_TIMEOUT, 300000L)
     server = KyuubiServer.startServer(conf)
